@@ -19,8 +19,9 @@
 
 
 // INCLUDES
-#include "platform.h"
-
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include "ConnectionHandler.hpp"
 #include "DataBuffer.hpp"
 #include "UDSocket.hpp"
@@ -40,12 +41,7 @@
 #include <sys/time.h>
 #include <fcntl.h>
 #include <sys/stat.h>
-
-#ifdef __GCCVER3
 #include <istream>
-#else
-#include <istream.h>
-#endif
 
 
 // GLOBALS
@@ -85,7 +81,7 @@ bool wasClean(String &url, const int fg)
 	try {
 		ipcsock.writeString(myurl.c_str());  // throws on err
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 #ifdef DGDEBUG
 		std::cerr << "Exception writing to url cache" << std::endl;
 		std::cerr << e.what() << std::endl;
@@ -97,7 +93,7 @@ bool wasClean(String &url, const int fg)
 	try {
 		ipcsock.readFromSocket(&reply, 1, 0, 6);  // throws on err
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 #ifdef DGDEBUG
 		std::cerr << "Exception reading from url cache" << std::endl;
 		std::cerr << e.what() << std::endl;
@@ -133,7 +129,7 @@ void addToClean(String &url, const int fg)
 	try {
 		ipcsock.writeString(myurl.c_str());  // throws on err
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 #ifdef DGDEBUG
 		std::cerr << "Exception adding to url cache" << std::endl;
 		std::cerr << e.what() << std::endl;
@@ -238,7 +234,7 @@ bool ConnectionHandler::gotIPs(std::string ipstr) {
 		ipcsock.writeToSockete(ipstr.c_str(), ipstr.length(), 0, 6);
 		ipcsock.readFromSocket(&reply, 1, 0, 6);  // throws on err
 	}
-	catch (exception& e) {
+	catch (std::exception& e) {
 #ifdef DGDEBUG
 		std::cerr << "Exception with IP cache" << std::endl;
 		std::cerr << e.what() << std::endl;
@@ -278,7 +274,7 @@ off_t ConnectionHandler::sendFile(Socket * peerconn, String & filename, String &
 	try {
 		peerconn->writeString(message.toCharArray());
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 		close(fd);
 		return 0;
 	}
@@ -297,7 +293,7 @@ off_t ConnectionHandler::sendFile(Socket * peerconn, String & filename, String &
 			std::cout << "error reading send file so throwing exception" << std::endl;
 #endif
 			delete[]buffer;
-			throw exception();
+			throw std::exception();
 		}
 		if (rc == 0) {
 #ifdef DGDEBUG
@@ -308,7 +304,7 @@ off_t ConnectionHandler::sendFile(Socket * peerconn, String & filename, String &
 		// as it's cached to disk the buffer must be reasonably big
 		if (!peerconn->writeToSocket(buffer, rc, 0, 100)) {
 			delete[]buffer;
-			throw exception();
+			throw std::exception();
 		}
 		sent += rc;
 #ifdef DGDEBUG
@@ -322,7 +318,7 @@ off_t ConnectionHandler::sendFile(Socket * peerconn, String & filename, String &
 
 // pass data between proxy and client, filtering as we go.
 // this is the only public function of ConnectionHandler - all content blocking/filtering is triggered from calls that live here.
-void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
+void ConnectionHandler::handleConnection(Socket &peerconn, String &ip)
 {
 	struct timeval thestart;
 	gettimeofday(&thestart, NULL);
@@ -443,7 +439,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 				header.reset();
 				try {
 					header.in(&peerconn, true, true);  // get header from client, allowing persistency and breaking on reloadconfig
-				} catch (exception &e) {
+				} catch (std::exception &e) {
 #ifdef DGDEBUG
 					std::cout << "Persistent connection closed" << std::endl;
 #endif
@@ -668,7 +664,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 					// The requested URL is malformed.
 					peerconn.writeString("</BODY></HTML>\n");
 				}
-				catch(exception & e) {
+				catch(std::exception & e) {
 				}
 				proxysock.close();  // close connection to proxy
 				break;
@@ -771,7 +767,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 						unlink(tempfilename.toCharArray());
 					}
 				}
-				catch(exception & e) {
+				catch(std::exception & e) {
 				}
 				proxysock.close();  // close connection to proxy
 				break;
@@ -862,10 +858,10 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 						String rtype(header.requestType());
 						doLog(clientuser, clientip, url, header.port, exceptionreason, rtype, docsize, (exceptioncat.length() ? &exceptioncat : NULL), false, isexception,
 							false, &thestart, cachehit, ((!isconnect && persist) ? docheader.returnCode() : 200),
-							mimetype, wasinfected, wasscanned, 0, filtergroup, &header, &docheader);
+							mimetype, wasinfected, wasscanned, 0, filtergroup, &header);
 					}
 				}
-				catch(exception & e) {
+				catch(std::exception & e) {
 				}
 				if (persist)
 					continue;
@@ -956,12 +952,12 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 								String rtype(header.requestType());
 								doLog(clientuser, clientip, url, header.port, exceptionreason, rtype, docsize, (exceptioncat.length() ? &exceptioncat : NULL),
 									false, isexception, false, &thestart, cachehit, ((!isconnect && persist) ? docheader.returnCode() : 200),
-									mimetype, wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header, &docheader,
+									mimetype, wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header,
 									// content wasn't modified, but URL was
 									false, true);
 							}
 						}
-						catch(exception & e) {
+						catch(std::exception & e) {
 						}
 						if (persist)
 							continue;
@@ -1006,7 +1002,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 					// as its ssl so we can't see the return header etc
 					// So preemptive banning is forced on with ssl unfortunately.
 					// It is unlikely to cause many problems though.
-					requestChecks(&header, &checkme, &urld, &clientip, &clientuser, filtergroup, &ispostblock, isbanneduser, isbannedip);
+					requestChecks(&header, &checkme, &urld, &clientip, &clientuser, filtergroup, isbanneduser, isbannedip);
 #ifdef DGDEBUG
 					std::cout << "done checking" << std::endl;
 #endif
@@ -1033,9 +1029,9 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 					doLog(clientuser, clientip, url, header.port, exceptionreason, rtype, docsize, &checkme.whatIsNaughtyCategories, false,
 						isexception, false, &thestart,
 						cachehit, (wasrequested ? docheader.returnCode() : 200), mimetype, wasinfected,
-						wasscanned, checkme.naughtiness, filtergroup, &header, &docheader, false, urlmodified);
+						wasscanned, checkme.naughtiness, filtergroup, &header, false, urlmodified);
 				}
-				catch(exception & e) {
+				catch(std::exception & e) {
 				}
 				if (persist)
 					continue;
@@ -1072,7 +1068,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 			// links not to be requested.
 			if (authed && !isbypass && !isexception && !checkme.isItNaughty) {
 				requestChecks(&header, &checkme, &urld, &clientip, &clientuser, filtergroup,
-					&ispostblock, isbanneduser, isbannedip);
+					isbanneduser, isbannedip);
 			}
 
 			if (!checkme.isItNaughty) {
@@ -1300,7 +1296,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 				// un-authed users.
 				if (!authed && !isbypass && !isexception && !checkme.isItNaughty && !docheader.authRequired()) {
 					requestChecks(&header, &checkme, &urld, &clientip, &clientuser, filtergroup,
-						&ispostblock, isbanneduser, isbannedip);
+						isbanneduser, isbannedip);
 				}
 
 				// check body from proxy
@@ -1333,7 +1329,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 #endif
 							String csmessage;
 							contentFilter(&docheader, &header, &docbody, &proxysock, &peerconn, &headersent, &pausedtoobig,
-								&docsize, &checkme, runav, wasclean, cachehit, filtergroup, &sendtoscanner, &clientuser, &clientip,
+								&docsize, &checkme, runav, wasclean, filtergroup, &sendtoscanner, &clientuser, &clientip,
 								&wasinfected, &wasscanned, isbypass, urld, urldomain, &scanerror, contentmodified, &csmessage);
 							if (csmessage.length() > 0) {
 #ifdef DGDEBUG
@@ -1343,7 +1339,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 							}
 						} else {
 							contentFilter(&docheader, &header, &docbody, &proxysock, &peerconn, &headersent, &pausedtoobig,
-								&docsize, &checkme, runav, wasclean, cachehit, filtergroup, &sendtoscanner, &clientuser, &clientip,
+								&docsize, &checkme, runav, wasclean, filtergroup, &sendtoscanner, &clientuser, &clientip,
 								&wasinfected, &wasscanned, isbypass, urld, urldomain, &scanerror, contentmodified, NULL);
 						}
 					}
@@ -1385,7 +1381,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 				doLog(clientuser, clientip, url, header.port, checkme.whatIsNaughtyLog,
 					rtype, docsize, &checkme.whatIsNaughtyCategories, true, false, false, &thestart,
 					cachehit, 403, mimetype, wasinfected, wasscanned, checkme.naughtiness, filtergroup,
-					&header, (wasrequested ? &docheader : NULL), contentmodified, urlmodified, headermodified);
+					&header, contentmodified, urlmodified, headermodified);
 				if (denyAccess(&peerconn, &proxysock, &header, &docheader, &url, &checkme, &clientuser,&clientip, filtergroup, ispostblock, headersent, wasinfected, scanerror))
 				{
 					return;  // not stealth mode
@@ -1423,7 +1419,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 					if (!logged) doLog(clientuser, clientip, url, header.port, exceptionreason,
 						rtype, docsize, &checkme.whatIsNaughtyCategories, false, isexception,
 						docheader.isContentType("text"), &thestart, cachehit, docheader.returnCode(), mimetype,
-						wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header, &docheader,
+						wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header,
 						contentmodified, urlmodified, headermodified);
 				}
 
@@ -1493,7 +1489,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 					if (!logged) doLog(clientuser, clientip, url, header.port, exceptionreason,
 						rtype, docsize, &checkme.whatIsNaughtyCategories, false, isexception,
 						docheader.isContentType("text"), &thestart, cachehit, docheader.returnCode(), mimetype,
-						wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header, &docheader,
+						wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header,
 						contentmodified, urlmodified, headermodified);
 				}
 			} else if (!ishead /*&& !docheader.isRedirection()*/) {	// was not supposed to be checked
@@ -1507,12 +1503,12 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 				if (!logged) doLog(clientuser, clientip, url, header.port, exceptionreason,
 					rtype, docsize, &checkme.whatIsNaughtyCategories, false, isexception,
 					docheader.isContentType("text"), &thestart, cachehit, docheader.returnCode(), mimetype,
-					wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header, &docheader,
+					wasinfected, wasscanned, checkme.naughtiness, filtergroup, &header,
 					contentmodified, urlmodified, headermodified);
 			}
 		} // while persist
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 #ifdef DGDEBUG
 		std::cerr << "connection handler caught an exception: " << e.what() << std::endl;
 #endif
@@ -1531,7 +1527,7 @@ void ConnectionHandler::handleConnection(Socket &peerconn, String &ip, int port)
 		char buff[2];
 		peerconn.readFromSocket(buff, 2, 0, 5);
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 		return;
 	}
 	return;
@@ -1542,7 +1538,7 @@ void ConnectionHandler::doLog(std::string &who, std::string &from, String &where
 		std::string &what, String &how, off_t &size, std::string *cat, bool isnaughty,
 		bool isexception, bool istext, struct timeval *thestart, bool cachehit,
 		int code, std::string &mimetype, bool wasinfected, bool wasscanned, int naughtiness, int filtergroup,
-		HTTPHeader* reqheader, HTTPHeader* respheader, bool contentmodified, bool urlmodified, bool headermodified)
+		HTTPHeader* reqheader, bool contentmodified, bool urlmodified, bool headermodified)
 {
 
 	// don't log if logging disabled entirely, or if it's an ad block and ad logging is disabled,
@@ -1673,7 +1669,7 @@ void ConnectionHandler::doLog(std::string &who, std::string &from, String &where
 			ipcsock.setTimeout(10);
 			ipcsock.writeString(data.c_str());
 			ipcsock.close();
-		} catch (exception &e) {
+		} catch (std::exception &e) {
 			syslog(LOG_INFO, "Could not write to logging process: %s", e.what());
 #ifdef DGDEBUG
 			std::cout << "Could not write to logging process: " << e.what() << std::endl;
@@ -1684,7 +1680,7 @@ void ConnectionHandler::doLog(std::string &who, std::string &from, String &where
 
 // check the request header is OK (client host/user/IP allowed to browse, site not banned, upload not too big)
 void ConnectionHandler::requestChecks(HTTPHeader *header, NaughtyFilter *checkme, String *urld,
-	std::string *clientip, std::string *clientuser, int filtergroup, bool *ispostblock,
+	std::string *clientip, std::string *clientuser, int filtergroup,
 	bool &isbanneduser, bool &isbannedip)
 {
 	if (isbannedip) {
@@ -1878,7 +1874,7 @@ bool ConnectionHandler::denyAccess(Socket * peerconn, Socket * proxysock, HTTPHe
 				try {	// writestring throws exception on error/timeout
 					(*peerconn).writeString(writestring.toCharArray());
 				}
-				catch(exception & e) {
+				catch(std::exception & e) {
 				}
 			} else {
 				// we're dealing with a non-SSL'ed request, and have the option of using the custom banned image/page directly
@@ -1925,7 +1921,7 @@ bool ConnectionHandler::denyAccess(Socket * peerconn, Socket * proxysock, HTTPHe
 						writestring += "</A></FONT></CENTER></BODY></HTML>\n";
 						try { // writestring throws exception on error/timeout
 							(*peerconn).writeString(writestring.toCharArray());
-						} catch (exception& e) {}
+						} catch (std::exception& e) {}
 					}
 					
 					// Mod by Ernest W Lessenger Mon 2nd February 2004
@@ -2086,7 +2082,7 @@ bool ConnectionHandler::denyAccess(Socket * peerconn, Socket * proxysock, HTTPHe
 			(*checkme).isItNaughty = false;  // dont block
 		}
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 	}
 	
 	// we blocked the request, so flush the client connection & close the proxy connection.
@@ -2094,7 +2090,7 @@ bool ConnectionHandler::denyAccess(Socket * peerconn, Socket * proxysock, HTTPHe
 		try {
 			(*peerconn).readyForOutput(10);  //as best a flush as I can
 		}
-		catch(exception & e) {
+		catch(std::exception & e) {
 		}
 		(*proxysock).close();  // close connection to proxy
 		// we said no to the request, so return true, indicating exit the connhandler
@@ -2106,7 +2102,7 @@ bool ConnectionHandler::denyAccess(Socket * peerconn, Socket * proxysock, HTTPHe
 // do content scanning (AV filtering) and naughty filtering
 void ConnectionHandler::contentFilter(HTTPHeader *docheader, HTTPHeader *header, DataBuffer *docbody,
 	Socket *proxysock, Socket *peerconn, int *headersent, bool *pausedtoobig, off_t *docsize, NaughtyFilter *checkme,
-	bool runav, bool wasclean, bool cachehit, int filtergroup, std::deque<bool> *sendtoscanner,
+	bool runav, bool wasclean, int filtergroup, std::deque<bool> *sendtoscanner,
 	std::string *clientuser, std::string *clientip, bool *wasinfected, bool *wasscanned, bool isbypass,
 	String &url, String &domain, bool *scanerror, bool &contentmodified, String *csmessage)
 {
