@@ -20,16 +20,9 @@
 
 // INCLUDES
 
-#include "platform.h"
-
-#include "FatController.hpp"
-#include "ConnectionHandler.hpp"
-#include "DynamicURLList.hpp"
-#include "DynamicIPList.hpp"
-#include "String.hpp"
-#include "SocketArray.hpp"
-#include "UDSocket.hpp"
-#include "SysV.hpp"
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 
 #include <syslog.h>
 #include <csignal>
@@ -42,18 +35,24 @@
 #include <fstream>
 #include <sys/time.h>
 #include <sys/poll.h>
+#include <istream>
+#include <map>
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <sys/select.h>
 
-#ifdef __SEGV_BACKTRACE
+#ifdef ENABLE_SEGV_BACKTRACE
 #include <execinfo.h>
 #endif
 
-#ifdef __GCCVER3
-#include <istream>
-#include <map>
-#else
-#include <istream.h>
-#include <map.h>
-#endif
+#include "FatController.hpp"
+#include "ConnectionHandler.hpp"
+#include "DynamicURLList.hpp"
+#include "DynamicIPList.hpp"
+#include "String.hpp"
+#include "SocketArray.hpp"
+#include "UDSocket.hpp"
+#include "SysV.hpp"
 
 
 // GLOBALS
@@ -86,7 +85,6 @@ UDSocket iplistsock;
 Socket *peersock(NULL);  // the socket which will contain the connection
 
 String peersockip;  // which will contain the connection ip
-int peersockport;  // port connection originates
 
 
 // DECLARATIONS
@@ -100,7 +98,7 @@ extern "C"
 	void sig_hup(int signo);  // This is so we know if we should re-read our config.
 	void sig_usr1(int signo);  // This is so we know if we should re-read our config but not kill current connections
 	void sig_childterm(int signo);
-#ifdef __SEGV_BACKTRACE
+#ifdef ENABLE_SEGV_BACKTRACE
 	void sig_segv(int signo/*, siginfo_t* info, void* p*/); // Generate a backtrace on segfault
 #endif
 }
@@ -126,7 +124,7 @@ int handle_connections(UDSocket &pipe);
 // tell a non-busy child process to accept the incoming connection
 void tellchild_accept(int num, int whichsock);
 // child process accept()s connection from server socket
-bool getsock_fromparent(UDSocket &fd/*, int &socknum*/);
+bool getsock_fromparent(UDSocket &fd);
 
 // add known info about a child to our info lists
 void addchild(int pos, int fd, pid_t child_pid);
@@ -136,8 +134,8 @@ int getfreechild();
 int getchildslot();
 // cull up to this number of non-busy children
 void cullchildren(int num);
-// delete this child from our info lists (pass in child's recorded exit value - currently unused)
-void deletechild(int child_pid, int stat);
+// delete this child from our info lists
+void deletechild(int child_pid);
 // clean up any dead child processes (calls deletechild with exit values)
 void mopup_afterkids();
 
@@ -189,23 +187,12 @@ extern "C"
 #endif
 		_exit(0);
 	}
-#ifdef __SEGV_BACKTRACE
-	void sig_segv(int signo/*, siginfo_t* info, void* p*/)
+#ifdef ENABLE_SEGV_BACKTRACE
+	void sig_segv(int signo)
 	{
 #ifdef DGDEBUG
 		std::cout << "SEGV received." << std::endl;
 #endif
-/*		char* str = "UNKNOWN";
-		switch (info->si_code)
-		{
-#ifdef SEGV_MAPERR
-		case SEGV_MAPERR: str = "SEGV_MAPERR"; break;
-#endif
-#ifdef SEGV_ACCERR
-		case SEGV_ACCERR: str = "SEGV_ACCERR"; break;
-#endif
-		}
-		syslog(LOG_ERR, "Segfault: %s", str);*/
 		// Generate backtrace
 		void *addresses[10];
 		char **strings;
@@ -213,7 +200,7 @@ extern "C"
 		strings = backtrace_symbols(addresses,c);
 		printf("backtrace returned: %d\n", c);
 		for (int i = 0; i < c; i++) {
-			syslog(LOG_ERR, "%d: %X ", i, (int)addresses[i]);
+			syslog(LOG_ERR, "%d: %zX ", i, (size_t)addresses[i]);
 			syslog(LOG_ERR, "%s", strings[i]);
 		}
 		// Kill off the current process
@@ -302,7 +289,7 @@ void flush_urlcache()
 	try {
 		fipcsock.writeString(request.toCharArray());  // throws on err
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 #ifdef DGDEBUG
 		std::cerr << "Exception flushing url cache" << std::endl;
 		std::cerr << e.what() << std::endl;
@@ -486,7 +473,7 @@ int send_readystatus(UDSocket &pipe)
 			return -1;
 		}
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 		return -1;
 	}
 	return 0;
@@ -515,9 +502,7 @@ int handle_connections(UDSocket &pipe)
 			toldparentready = true;
 		}
 
-		//int socknum;
-
-		if (!getsock_fromparent(pipe/*, socknum*/)) {	// blocks waiting for a few mins
+		if (!getsock_fromparent(pipe)) {	// blocks waiting for a few mins
 			continue;
 		}
 		toldparentready = false;
@@ -529,7 +514,7 @@ int handle_connections(UDSocket &pipe)
 			continue;
 		}
 
-		h.handleConnection(*peersock, peersockip, peersockport/*, socknum*/);  // deal with the connection
+		h.handleConnection(*peersock, peersockip);  // deal with the connection
 		delete peersock;
 	}
 	if (!(++cycle) && o.logchildprocs)
@@ -546,7 +531,7 @@ int handle_connections(UDSocket &pipe)
 }
 
 // the parent process recieves connections - children receive notifications of this over their socketpair, and accept() them for handling
-bool getsock_fromparent(UDSocket &fd/*, int &socknum*/)
+bool getsock_fromparent(UDSocket &fd)
 {
 	String message;
 	char buf;
@@ -554,7 +539,7 @@ bool getsock_fromparent(UDSocket &fd/*, int &socknum*/)
 	try {
 		rc = fd.readFromSocket(&buf, 1, 0, 360, true, true);  // blocks for a few mins
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 		// whoop! we received a SIGHUP. we should reload our configuration - and no, we didn't get an FD.
 
 		reloadconfig = true;
@@ -572,16 +557,14 @@ bool getsock_fromparent(UDSocket &fd/*, int &socknum*/)
 	}
 
 	// woo! we have a connection. accept it.
-	//socknum = (int)buf;
 	peersock = serversockets[buf]->accept();
 	peersockip = peersock->getPeerIP();
-	peersockport = peersock->getPeerSourcePort();
 
 	try {
 		fd.writeToSockete("K", 1, 0, 10, true);  // need to make parent wait for OK
 		// so effectively providing a lock
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 		if (o.logconerror)
 			syslog(LOG_ERR, "Error telling parent we accepted: %s", e.what());
 		peersock->close();
@@ -615,11 +598,7 @@ void mopup_afterkids()
 		if (pid < 1) {
 			break;
 		}
-		if (WIFEXITED(stat_val)) {	// exited normally
-			deletechild((int) pid, WEXITSTATUS(stat_val));
-		} else {
-			deletechild((int) pid, -1);
-		}
+		deletechild((int) pid);
 	}
 }
 
@@ -652,7 +631,7 @@ void addchild(int pos, int fd, pid_t child_pid)
 void cullchildren(int num)
 {
 #ifdef DGDEBUG
-	cout << "culling childs:" << num << endl;
+	std::cout << "culling childs:" << num << std::endl;
 #endif
 	int i;
 	int count = 0;
@@ -676,7 +655,7 @@ void cullchildren(int num)
 void kill_allchildren()
 {
 #ifdef DGDEBUG
-	cout << "killing all childs:" << endl;
+	std::cout << "killing all childs:" << std::endl;
 #endif
 	for (int i = o.max_children - 1; i >= 0; i--) {
 		if (childrenstates[i] >= 0) {
@@ -694,7 +673,7 @@ void kill_allchildren()
 void hup_allchildren()
 {
 #ifdef DGDEBUG
-	cout << "huping all childs:" << endl;
+	std::cout << "huping all childs:" << std::endl;
 #endif
 	for (int i = o.max_children - 1; i >= 0; i--) {
 		if (childrenstates[i] >= 0) {
@@ -725,9 +704,9 @@ bool check_kid_readystatus(int tofind)
 			try {
 				rc = childsockets[f]->getLine(buf, 4, 100, true);
 			}
-			catch(exception & e) {
+			catch(std::exception & e) {
 				kill(childrenpids[f], SIGTERM);
-				deletechild(childrenpids[f], -1);
+				deletechild(childrenpids[f]);
 				tofind--;
 				continue;
 			}
@@ -742,7 +721,7 @@ bool check_kid_readystatus(int tofind)
 				}
 			} else {	// child -> parent communications failure so kill it
 				kill(childrenpids[f], SIGTERM);
-				deletechild(childrenpids[f], -1);
+				deletechild(childrenpids[f]);
 				tofind--;
 			}
 		}
@@ -758,23 +737,24 @@ bool check_kid_readystatus(int tofind)
 }
 
 // remove child from our PID/FD and slot lists
-void deletechild(int child_pid, int stat)
+void deletechild(int child_pid)
 {
 	int i;
 	for (i = 0; i < o.max_children; i++) {
 		if (childrenpids[i] == child_pid) {
 			childrenpids[i] = -1;
+			// Delete a busy child
 			if (childrenstates[i] == 1) {
-				//if (stat == 2) {
-					busychildren--;
-				/*} else {
-					busychildren--;  // should only happen if kid goes screwy
-					// child calls _exit with return value of handle_connections,
-					// so if it's nonzero, it means there was an error in there somewhere
-				}*/
+				busychildren--;
 			}
-			if (childrenstates[i] != -2) {	// -2 is when its been culled
-				numchildren--;  // so no need to duplicater
+			// Delete a child which isn't "ready" yet
+			if (childrenstates[i] == 4) {
+				busychildren--;
+				waitingfor--;
+			}
+			// Common code for any non-"culled" child
+			if (childrenstates[i] != -2) {
+				numchildren--;
 				delete childsockets[i];
 				childsockets[i] = NULL;
 				pids[i].fd = -1;
@@ -808,9 +788,9 @@ void tellchild_accept(int num, int whichsock)
 	// include server socket number in message
 	try {
 		childsockets[num]->writeToSockete((char*)&whichsock, 1, 0, 5, true);
-	} catch(exception & e) {
+	} catch(std::exception & e) {
 		kill(childrenpids[num], SIGTERM);
-		deletechild(childrenpids[num], -1);
+		deletechild(childrenpids[num]);
 		return;
 	}
 
@@ -818,9 +798,9 @@ void tellchild_accept(int num, int whichsock)
 	char buf;
 	try {
 		childsockets[num]->readFromSocket(&buf, 1, 0, 5, false, true);
-	} catch(exception & e) {
+	} catch(std::exception & e) {
 		kill(childrenpids[num], SIGTERM);
-		deletechild(childrenpids[num], -1);
+		deletechild(childrenpids[num]);
 		return;
 	}
 	// no need to check what it actually contains,
@@ -855,11 +835,11 @@ int log_listener(std::string log_location, bool logconerror, bool logsyslog)
 	UDSocket* ipcpeersock;  // the socket which will contain the ipc connection
 	int rc, ipcsockfd;
 
-#ifdef __EMAIL
+#ifdef ENABLE_EMAIL
 	// Email notification patch by J. Gauthier
-	map<string,int> violation_map;
-	map<string,int> timestamp_map;   
-	map<string,string> vbody_map;
+	std::map<std::string, int> violation_map;
+	std::map<std::string, int> timestamp_map;   
+	std::map<std::string, std::string> vbody_map;
 
 	int curv_tmp, stamp_tmp, byuser;
 #endif
@@ -873,9 +853,9 @@ int log_listener(std::string log_location, bool logconerror, bool logsyslog)
 	long tv_sec = 0, tv_usec = 0;
 	int contentmodified = 0, urlmodified = 0, headermodified = 0;
 
-	ofstream* logfile = NULL;
+	std::ofstream* logfile = NULL;
 	if (!logsyslog) {
-		logfile = new ofstream(log_location.c_str(), ios::app);
+		logfile = new std::ofstream(log_location.c_str(), std::ios::app);
 		if (logfile->fail()) {
 			syslog(LOG_ERR, "Error opening/creating log file.");
 #ifdef DGDEBUG
@@ -1023,7 +1003,7 @@ int log_listener(std::string log_location, bool logconerror, bool logsyslog)
 					}
 					delete[]logline;
 				}
-				catch(exception & e) {
+				catch(std::exception & e) {
 					delete ipcpeersock;
 					if (logconerror)
 						syslog(LOG_ERR, "Error reading ipc. (Ignorable)");
@@ -1237,7 +1217,7 @@ int log_listener(std::string log_location, bool logconerror, bool logsyslog)
 #endif
 			delete ipcpeersock;  // close the connection
 
-#ifdef __EMAIL
+#ifdef ENABLE_EMAIL
 			// do the notification work here, but fork for speed
 			if (o.fg[filtergroup]->use_smtp==true) {
 
@@ -1498,7 +1478,7 @@ int url_list_listener(bool logconerror)
 			try {
 				rc = ipcpeersock->getLine(logline, 32000, 3, true);  // throws on err
 			}
-			catch(exception & e) {
+			catch(std::exception & e) {
 				delete ipcpeersock;  // close the connection
 				if (logconerror) {
 #ifdef DGDEBUG
@@ -1539,7 +1519,7 @@ int url_list_listener(bool logconerror)
 			try {
 				ipcpeersock->writeToSockete(&reply, 1, 0, 6);
 			}
-			catch(exception & e) {
+			catch(std::exception & e) {
 				delete ipcpeersock;  // close the connection
 				if (logconerror) {
 					syslog(LOG_ERR, "%s", "Error writing url ipc. (Ignorable)");
@@ -1664,7 +1644,7 @@ int ip_list_listener(std::string stat_location, bool logconerror) {
 			}
 			try {
 				rc = ipcpeersock->getLine(inbuff, 16, 3);  // throws on err
-			} catch (exception& e) {
+			} catch (std::exception& e) {
 				delete ipcpeersock;
 				if (logconerror) {
 #ifdef DGDEBUG
@@ -1686,7 +1666,7 @@ int ip_list_listener(std::string stat_location, bool logconerror) {
 				reply = 'N';
 			try {
 				ipcpeersock->writeToSockete(&reply, 1, 0, 6);
-			} catch (exception& e) {
+			} catch (std::exception& e) {
 				delete ipcpeersock;
 				if (logconerror) {
 #ifdef DGDEBUG
@@ -2048,7 +2028,7 @@ int fc_controlit()
 		return (1);
 	}
 
-#ifdef __SEGV_BACKTRACE
+#ifdef ENABLE_SEGV_BACKTRACE
 	memset(&sa, 0, sizeof(sa));
 	sa.sa_handler = &sig_segv;
 	if (sigaction(SIGSEGV, &sa, NULL)) {
@@ -2122,7 +2102,6 @@ int fc_controlit()
 		syslog(LOG_ERR, "%s", "Error creating initial fork pool - exiting...");
 	}
 
-	bool preforked = true;
 	int tofind;
 	reloadconfig = false;
 
@@ -2137,7 +2116,7 @@ int fc_controlit()
 		// OR, we need to exit to reread config
 		if (gentlereload) {
 #ifdef DGDEBUG
-			cout << "gentle reload activated" << endl;
+			std::cout << "gentle reload activated" << std::endl;
 #endif
 			o.deleteFilterGroups();
 			if (!o.readFilterGroupConf()) {
@@ -2199,16 +2178,14 @@ int fc_controlit()
 		tofind = rc;
 		if (rc > 0) {
 			for (i = o.max_children; i < fds; i++) {
-				if ((pids[i].revents & POLLIN) > 0) {
+				if (pids[i].revents) {
 					tofind--;
 				}
 			}
 		}
 
 		if (tofind > 0) {
-			if (check_kid_readystatus(tofind)) {
-				preforked = false;  // we are no longer waiting last prefork
-			}
+			check_kid_readystatus(tofind);
 		}
 
 		freechildren = numchildren - busychildren;
@@ -2222,16 +2199,11 @@ int fc_controlit()
 
 		if (rc > 0) {
 			for (i = o.max_children; i < fds; i++) {
-				if ((pids[i].revents & (POLLERR | POLLHUP | POLLNVAL)) > 0) {
-					ttg = true;
-					syslog(LOG_ERR, "Error with main listening socket.  Exiting.");
-					continue;
-				}
 				if ((pids[i].revents & POLLIN) > 0) {
 					// socket ready to accept() a connection
 					failurecount = 0;  // something is clearly working so reset count
 					if (freechildren < 1 && numchildren < o.max_children) {
-						if (!preforked) {
+						if (waitingfor == 0) {
 							int num = o.prefork_children;
 							if ((o.max_children - numchildren) < num)
 								num = o.max_children - numchildren;
@@ -2242,8 +2214,8 @@ int fc_controlit()
 								syslog(LOG_ERR, "Error forking %d extra process(es).", num);
 								failurecount++;
 							}
-							preforked = true;
-						}
+						} else
+							usleep(1000);
 						continue;
 					}
 					if (freechildren > 0) {
@@ -2255,14 +2227,20 @@ int fc_controlit()
 						usleep(1000);
 					}
 				}
+				else if (pids[i].revents) {
+					ttg = true;
+					syslog(LOG_ERR, "Error with main listening socket.  Exiting.");
+					break;
+				}
 			}
+			if (ttg)
+				break;
 		}
 
-		if (freechildren < o.minspare_children && !preforked && numchildren < o.max_children) {
+		if (freechildren < o.minspare_children && (waitingfor == 0) && numchildren < o.max_children) {
 			if (o.logchildprocs)
 				syslog(LOG_ERR, "Fewer than %d free children - Spawning %d process(es)", o.minspare_children, o.prefork_children);
 			rc = prefork(o.prefork_children);
-			preforked = true;
 			if (rc < 0) {
 				syslog(LOG_ERR, "Error forking preforkchildren extra processes.");
 				failurecount++;
@@ -2274,17 +2252,12 @@ int fc_controlit()
 		}
 		if (freechildren > o.maxspare_children) {
 			time(&tnow);
-			if ((tnow - tmaxspare) > (2 * 60)) {	// 2 * 60
+			if ((tnow - tmaxspare) > (2 * 60)) {
 				if (o.logchildprocs)
 					syslog(LOG_ERR, "More than %d free children - Killing %d process(es)", o.maxspare_children, freechildren - o.maxspare_children);
 				cullchildren(freechildren - o.maxspare_children);
 			}
 		}
-
-		// yield CPU for a while. this loop does not explicitly sleep other
-		// than when polling FDs; when connections are coming in at a rate of
-		// knots, it effectively turns into a busy loop. this should help.
-		//usleep(1000);
 	}
 	cullchildren(numchildren);  // remove the fork pool of spare children
 	for (int i = 0; i < o.max_children; i++) {
