@@ -22,6 +22,9 @@
 
 // INCLUDES
 
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include <syslog.h>
 #include <algorithm>
 #include "ListContainer.hpp"
@@ -159,7 +162,7 @@ bool ListContainer::readPhraseList(const char *filename, bool isexception, int c
 	}
 	filedate = getFileDate(filename);
 	increaseMemoryBy(len + 2);  // Allocate some memory to hold file
-	ifstream listfile(filename, ios::in);  // open the file for reading
+	std::ifstream listfile(filename, std::ios::in);  // open the file for reading
 	if (!listfile.good()) {
 		if (!is_daemonised) {
 			std::cerr << "Error opening file (does it exist?): " << filename << std::endl;
@@ -385,7 +388,7 @@ bool ListContainer::readItemList(const char *filename, bool startswith, int filt
 	}
 	increaseMemoryBy(len + 2);  // Allocate some memory to hold file
 	// The plus one is to cope with files not ending in a new line
-	ifstream listfile(filename, ios::in);
+	std::ifstream listfile(filename, std::ios::in);
 	if (!listfile.good()) {
 		if (!is_daemonised) {
 			std::cerr << "Error opening: " << filename << std::endl;
@@ -434,9 +437,20 @@ bool ListContainer::readItemList(const char *filename, bool startswith, int filt
 			continue;
 		}
 
-		if (temp.contains("#")) {
-			temp = temp.before("#");  // tidy up
+		// Strip off comments that don't necessarily start at the beginning of a line
+		// - but not regular expression comments
+		std::string::size_type commentstart = 1;
+		while ((commentstart = temp.find_first_of('#', commentstart)) != std::string::npos)
+		{
+			// Don't treat "(?#...)" as a DG comment - it's a regex comment
+			if (temp[commentstart - 1] != '?')
+			{
+				temp = temp.substr(0, commentstart);
+				break;
+			}
+			++commentstart;
 		}
+
 		temp.removeWhiteSpace();  // tidy up and make it handle CRLF files
 		if (temp.startsWith(".Include<")) {	// see if we have another list
 			inc = temp.after(".Include<");  // to include
@@ -811,7 +825,7 @@ bool ListContainer::createCacheFile()
 #ifdef DGDEBUG
 	std::cout << "creating processed file:" << f << std::endl;
 #endif
-	ofstream listfile(f.toCharArray(), ios::out);
+	std::ofstream listfile(f.toCharArray(), std::ios::out);
 	if (listfile.fail()) {
 		if (!is_daemonised) {
 			std::cerr << "Error creating cache file. Do you have write access to this area: \"" << f << "\"?" << std::endl;
@@ -1454,7 +1468,7 @@ bool ListContainer::readProcessedItemList(const char *filename, bool startswith,
 		return false;
 	}
 	increaseMemoryBy(len + 2);
-	ifstream listfile(filename, ios::in);
+	std::ifstream listfile(filename, std::ios::in);
 	if (!listfile.good()) {
 		if (!is_daemonised) {
 			std::cerr << "Error opening: " << filename << std::endl;
