@@ -25,8 +25,6 @@
 
 // INLCUDES
 
-#include "platform.h"
-
 #include <vector>
 #include <deque>
 #include <map>
@@ -37,7 +35,7 @@
 // DECLARATIONS
 
 // time limit information
-typedef struct TimeLimit {
+struct TimeLimit {
 	unsigned int sthour, stmin, endhour, endmin;
 	String days, timetag;
 };
