@@ -21,6 +21,9 @@
 
 
 // INCLUDES
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include "ListManager.hpp"
 
 #include <syslog.h>
