@@ -20,6 +20,9 @@
 
 // INCLUDES
 
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include "NaughtyFilter.hpp"
 #include "RegExp.hpp"
 #include "ListContainer.hpp"
@@ -32,7 +35,7 @@
 
 extern OptionContainer o;
 
-#ifdef __PCRE
+#ifdef HAVE_PCRE
 extern RegExp absurl_re, relurl_re;
 #endif
 
@@ -392,7 +395,7 @@ void NaughtyFilter::checkme(DataBuffer *body, String &url, String &domain)
 #ifdef DGDEBUG
 		std::cout << "Checking smart content" << std::endl;
 #endif
-		checkphrase(bodynohtml, j);
+		checkphrase(bodynohtml, j - 1);
 
 		// second time round the case loop (if there is a second time),
 		// do preserve case (exotic encodings)
@@ -434,7 +437,7 @@ void NaughtyFilter::checkphrase(char *file, int l, String *url, String *domain)
 	// if a src/href URL starts with a /, append it to the domain; otherwise, append it to the existing URL.
 	// chop off anything after a ?, run through realPath, then put through the URL lists.
 
-#ifdef __PCRE
+#ifdef HAVE_PCRE
 	// if weighted phrases are enabled, and we have been passed a URL and domain, and embedded URL checking is enabled...
 	// then check for embedded URLs!
 	if (url != NULL && o.fg[filtergroup]->embedded_url_weight > 0) {
@@ -988,7 +991,7 @@ void NaughtyFilter::checkPICSrating(std::string label)
 	}
 }
 
-void NaughtyFilter::checkPICSagainstoption(String s, char *l, int opt, std::string m)
+void NaughtyFilter::checkPICSagainstoption(String s, const char *l, int opt, std::string m)
 {
 	if (s.indexOf(l) != -1) {
 		// if the rating contains the label then:
