@@ -20,6 +20,9 @@
 
 // INCLUDES
 
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include "OptionContainer.hpp"
 #include "RegExp.hpp"
 #include "ConfigVar.hpp"
@@ -105,7 +108,7 @@ bool OptionContainer::read(const char *filename, int type)
 		std::string linebuffer;
 		String temp;  // for tempory conversion and storage
 		int j;  // counter
-		ifstream conffiles(filename, ios::in);  // dansguardian.conf
+		std::ifstream conffiles(filename, std::ios::in);  // dansguardian.conf
 		if (!conffiles.good()) {
 			if (!is_daemonised) {
 				std::cerr << "error reading: " << filename << std::endl;
@@ -145,20 +148,20 @@ bool OptionContainer::read(const char *filename, int type)
 
 			if ((pid_filename = findoptionS("pidfilename")) == "") {
 				pid_filename = __PIDDIR;
-				pid_filename += "dansguardian.pid";
+				pid_filename += "/dansguardian.pid";
 			}
 
 			if (findoptionS("logsyslog") == "on") {
 				log_syslog = true;
 			} else 	if ((log_location = findoptionS("loglocation")) == "") {
 				log_location = __LOGLOCATION;
-				log_location += "access.log";
+				log_location += "/access.log";
 				log_syslog = false;
 			}
 
 			if ((stat_location = findoptionS("statlocation")) == "") {
 				stat_location = __LOGLOCATION;
-				stat_location += "stats";
+				stat_location += "/stats";
 			}
 
 			if (type == 0) {
@@ -192,7 +195,7 @@ bool OptionContainer::read(const char *filename, int type)
 			soft_restart = false;
 		}
 
-#ifdef __EMAIL
+#ifdef ENABLE_EMAIL
 		// Email notification patch by J. Gauthier
 		mailer = findoptionS("mailer");
 #endif
@@ -530,7 +533,7 @@ bool OptionContainer::read(const char *filename, int type)
 
 		filter_groups_list_location = findoptionS("filtergroupslist");
 		std::string banned_ip_list_location(findoptionS("bannediplist"));
-		std::string exceptions_ip_list_location(findoptionS("exceptioniplist"));
+		std::string exception_ip_list_location(findoptionS("exceptioniplist"));
 		group_names_list_location = findoptionS("groupnamesfile");
 		std::string language_list_location(languagepath + "messages");
 		if (reporting_level == 1 || reporting_level == 2) {
@@ -547,7 +550,7 @@ bool OptionContainer::read(const char *filename, int type)
 			}
 			if (access_denied_domain.length() < 4) {
 				if (!is_daemonised) {
-					cerr << "accessdeniedaddress setting appears to be wrong." << endl;
+					std::cerr << "accessdeniedaddress setting appears to be wrong." << std::endl;
 				}
 				syslog(LOG_ERR, "%s", "accessdeniedaddress setting appears to be wrong.");
 				return false;
@@ -574,12 +577,16 @@ bool OptionContainer::read(const char *filename, int type)
 			use_group_names_list = true;
 		}
 
-		if (!doReadItemList(banned_ip_list_location.c_str(),&banned_ip_list,"bannediplist",true)) {
+		if (!exception_ip_list.readIPMelangeList(exception_ip_list_location.c_str()))
+		{
+			std::cout << "Failed to read exceptioniplist" << std::endl;
 			return false;
-		}		// read banned ip list
-		if (!doReadItemList(exceptions_ip_list_location.c_str(),&exception_ip_list,"exceptioniplist",false)) {
+		}
+		if (!banned_ip_list.readIPMelangeList(banned_ip_list_location.c_str()))
+		{
+			std::cout << "Failed to read bannediplist" << std::endl;
 			return false;
-		}		// ip exceptions
+		}
 
 		if (!language_list.readLanguageList(language_list_location.c_str())) {
 			return false;
@@ -605,7 +612,7 @@ bool OptionContainer::read(const char *filename, int type)
 		}
 
 	}
-	catch(exception & e) {
+	catch(std::exception & e) {
 		if (!is_daemonised) {
 			std::cerr << e.what() << std::endl;  // when called the daemon has not
 			// detached so we can do this
@@ -631,53 +638,14 @@ bool OptionContainer::doReadItemList(const char* filename, ListContainer* lc, co
 	return true;
 }
 
-bool OptionContainer::inIPList(const std::string *ip, ListContainer& list, std::string *&host)
-{
-	if ((*ip).length() < 1) {
-		return false;
-	}
-	if (list.inList((char *) (*ip).c_str())) {
-		delete host;
-		host = NULL;
-		return true;
-	}
-	else if (reverse_client_ip_lookups) {
-		std::deque<String > *hostnames = ipToHostname((*ip).c_str());
-		bool result;
-		for (std::deque<String>::iterator i = hostnames->begin(); i != hostnames->end(); i++) {
-			result = list.inList(i->toCharArray());
-			if (result) {
-				// return the matched host name for logging purposes
-				// hey.. since the lookup is the hard part, not the logging,
-				// why not always return a hostname if it wasn't a straight IP
-				// that triggered the match?
-				//if (log_client_hostnames) {
-					delete host;
-					host = new std::string(i->toCharArray());
-#ifdef DGDEBUG
-					std::cout<<"Found hostname: "<<(*host)<<std::endl;
-#endif
-				//}
-				return true;
-			}
-		}
-		if ((log_client_hostnames) && (host == NULL) && (hostnames->size() > 0))
-			host = new std::string(hostnames->front().toCharArray());
-		delete hostnames;
-	}
-	return false;
-}
-
-// checkme: remove these and make inIPList public?
-
 bool OptionContainer::inExceptionIPList(const std::string *ip, std::string *&host)
 {
-	return inIPList(ip, exception_ip_list, host);
+	return exception_ip_list.inList(*ip, host);
 }
 
 bool OptionContainer::inBannedIPList(const std::string *ip, std::string *&host)
 {
-	return inIPList(ip, banned_ip_list, host);
+	return banned_ip_list.inList(*ip, host);
 }
 
 
@@ -754,7 +722,7 @@ std::deque<String > OptionContainer::findoptionM(const char *option)
 	return results;
 }
 
-bool OptionContainer::realitycheck(long int l, long int minl, long int maxl, char *emessage)
+bool OptionContainer::realitycheck(long int l, long int minl, long int maxl, const char *emessage)
 {
 	// realitycheck checks an amount for certain expected criteria
 	// so we can spot problems in the conf files easier
