@@ -24,8 +24,6 @@
 
 // INCLUDES
 
-#include "platform.h"
-
 #include "DownloadManager.hpp"
 #include "ContentScanner.hpp"
 #include "String.hpp"
@@ -37,6 +35,7 @@
 #include "ImageContainer.hpp"
 #include "RegExp.hpp"
 #include "Auth.hpp"
+#include "IPList.hpp"
 
 #include <deque>
 
@@ -112,7 +111,7 @@ public:
 	bool log_user_agent;
 	bool soft_restart;
 
-#ifdef __EMAIL
+#ifdef ENABLE_EMAIL
 	// Email notification patch by J. Gauthier
 	std::string mailer;   
 #endif
@@ -133,8 +132,8 @@ public:
 
 	HTMLTemplate html_template;
 	ListContainer filter_groups_list;
-	ListContainer exception_ip_list;
-	ListContainer banned_ip_list;
+	IPList exception_ip_list;
+	IPList banned_ip_list;
 	LanguageContainer language_list;
 	ImageContainer banned_image;
 
@@ -185,7 +184,7 @@ private:
 	bool precompileregexps();
 	long int findoptionI(const char *option);
 	std::string findoptionS(const char *option);
-	bool realitycheck(long int l, long int minl, long int maxl, char *emessage);
+	bool realitycheck(long int l, long int minl, long int maxl, const char *emessage);
 	bool readAnotherFilterGroupConf(const char *filename, const char *groupname, bool &need_html);
 	std::deque<String> findoptionM(const char *option);
 
