@@ -22,6 +22,9 @@
 
 // INCLUDES
 
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include "String.hpp"
 #include "md5.hpp"
 
@@ -61,7 +64,7 @@ String::String(const long unsigned int num)
 	buf << num << std::ends;
 	*this = buf.str();
 }
-# ifndef __OFFT_COLLISION
+# ifndef OFFT_COLLISION
 // If large file support is not enabled (and possibly even if it is),
 // the type of off_t may be a typedef of a type for which we already
 // have a constructor. In that case, don't define one which takes an
@@ -120,7 +123,7 @@ String::String(const long unsigned num)
 	*this = data;
 	delete[] data;
 }
-# ifndef __OFFT_COLLISION
+# ifndef OFFT_COLLISION
 // If large file support is not enabled (and possibly even if it is),
 // the type of off_t may be a typedef of a type for which we already
 // have a constructor. In that case, don't define one which takes an
