@@ -26,8 +26,6 @@
 
 // INCLUDES
 
-#include "platform.h"
-
 #include <iostream>
 #include <string>
 #include <sys/types.h>
@@ -49,7 +47,7 @@ public:
 	String(const long num);
 	String(const long unsigned num);
 	String(const unsigned int num);
-# ifndef __OFFT_COLLISION
+# ifndef OFFT_COLLISION
 	// If large file support is not enabled (and possibly even if it is),
 	// the type of off_t may be a typedef of a type for which we already
 	// have a constructor. In that case, don't define one which takes an
